==> wikirepo-0.0.1-py3-none-any.whl: wikirepo/data/economic/nom_gdp_per_cap.py <==
# =============================================================================
# Functions querying 'P2132' (nominal GDP per capita) information
#
# Contents
# --------
#   0. No Class
#       query_nom_gdp_per_cap
# =============================================================================

from wikirepo.data import data_utils

pid = 'P2132'
sub_pid = None
col_name = 'nom_gdp_per_cap'
col_prefix = None
ignore_char = ''
span = False

def query_nom_gdp_per_cap(dir_name=None,
                          ents_dict=None,
                          depth=0,
                          locations=None, 
                          time_lvl=None, 
                          timespan=None):
    """
    Queries the nominal GDP per capita for given location(s) over the given time_lvl and timespan
    """
    df, ents_dict = data_utils.query_wd_prop(dir_name=dir_name,
                                             ents_dict=ents_dict,
                                             depth=depth,
                                             locations=locations, 
                                             time_lvl=time_lvl, 
                                             timespan=timespan,
                                             pid=pid,
                                             sub_pid=sub_pid,
                                             col_name=col_name,
                                             col_prefix=col_prefix,
                                             ignore_char=ignore_char,
                                             span=span)

    return df, ents_dict

==> wikirepo-0.0.2-py3-none-any.whl: wikirepo/data/economic/nom_gdp_per_cap.py <==
# =============================================================================
# Functions querying 'P2132' (nominal GDP per capita) information
#
# Contents
# --------
#   0. No Class
#       query_prop_data
# =============================================================================

from wikirepo.data import data_utils

pid = 'P2132'
sub_pid = None
col_name = 'nom_gdp_per_cap'
col_prefix = None
ignore_char = ''
span = False

def query_prop_data(dir_name=None,
                    ents_dict=None,
                    depth=0,
                    locations=None, 
                    time_lvl=None, 
                    timespan=None):
    """
    Queries data for the module property for given region(s) over given depth, time_lvl and timespan
    """
    df, ents_dict = data_utils.query_wd_prop(dir_name=dir_name,
                                             ents_dict=ents_dict,
                                             depth=depth,
                                             locations=locations, 
                                             time_lvl=time_lvl, 
                                             timespan=timespan,
                                             pid=pid,
                                             sub_pid=sub_pid,
                                             col_name=col_name,
                                             col_prefix=col_prefix,
                                             ignore_char=ignore_char,
                                             span=span)

    return df, ents_dict
